""" Shallow Water Wave Module.

    This module performs the shallow water wave simulation, and is a
    specialisation of the ANUGA domain. It contains supporting modules and
    extra boundary classes to do with this specific domain.
"""

from numpy._pytesttester import PytestTester
test = PytestTester(__name__)
del PytestTester




 
